<?php
/* $Id: polish-utf-8.inc.php,v 2.99 2005/10/30 10:03:50 nijel Exp $ */

$charset = 'utf-8';
$allow_recoding = TRUE;
$text_dir = 'ltr';
$left_font_family = 'verdana, "arial ce", arial, helvetica, geneva, sans-serif';
$right_font_family = 'tahoma, verdana, "arial ce", arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ' ';
$number_decimal_separator = ',';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('bajtów', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Nie', 'Pon', 'Wto', 'Śro', 'Czw', 'Pią', 'Sob');
$month = array('Sty', 'Lut', 'Mar', 'Kwi', 'Maj', 'Cze', 'Lip', 'Sie', 'Wrz', 'Paź', 'Lis', 'Gru');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d %B %Y, %H:%M';
$timespanfmt = '%s dni, %s godzin, %s minut i %s sekund';

$strAbortedClients = 'Przerwane';
$strAbsolutePathToDocSqlDir = 'Proszę podać bezwzględną ścieżkę na serwerze www do katalogu docSQL';
$strAccessDenied = 'Brak dostępu';
$strAccessDeniedExplanation = 'phpMyAdmin próbował połączyć się z serwerem MySQL, a serwer odrzucił połączenie. Powinieneś sprawdzić nazwę hosta, nazwę użytkownika i hasło w pliku config.inc.php i upewnić się, że odpowiadają one informacjom danym przez administratora serwera MySQL.';
$strAction = 'Działanie';
$strAddAutoIncrement = 'Dodaj wartości AUTO_INCREMENT';
$strAddConstraints = 'Dodaj ograniczenia';
$strAddDeleteColumn = 'Dodaj/usuń pola';
$strAddDeleteRow = 'Dodaj/usuń wiersz kryteriów';
$strAddDropDatabase = 'Dodaj DROP DATABASE';
$strAddedColumnComment = 'Został dodany komentarz kolumny';
$strAddedColumnRelation = 'Została dodana relacja dla kolumny';
$strAddFields = 'Dodaj %s pól';
$strAddHeaderComment = 'Dodaj do nagłówka własny komentarz (\\n oddziela linie)';
$strAddIfNotExists = 'Dodaj IF NOT EXISTS';
$strAddIntoComments = 'Dodaj w komentarzach:';
$strAddNewField = 'Dodaj nowego pole';
$strAddPrivilegesOnDb = 'Dodaj uprawnienia dla następującej bazy danych';
$strAddPrivilegesOnTbl = 'Dodaj uprawnienia dla następującej tabeli';
$strAddSearchConditions = 'Dodaj warunki przeszukiwania (warunek dla "where"):';
$strAddToIndex = 'Dodaj &nbsp;%s&nbsp;kolumn do indeksu ';
$strAddUser = 'Dodaj nowego użytkownika';
$strAddUserMessage = 'Nowy użytkownik został dodany.';
$strAdministration = 'Administracja';
$strAffectedRows = 'Zmodyfikowanych rekordów:';
$strAfterInsertBack = 'Powrót';
$strAfterInsertNewInsert = 'Wstaw nowy rekord';
$strAfterInsertNext = 'Edytuj następny rekord';
$strAfterInsertSame = 'Powrót do tej strony';
$strAfter = 'Po %s';
$strAllTableSameWidth = 'wyświetlić wszystkie tabele z taką samą szerokością?';
$strAll = 'Wszystko';
$strAlterOrderBy = 'Sortowanie tabeli wg';
$strAnalyzeTable = 'Analizuj tabelę';
$strAnd = 'oraz';
$strAndThen = 'a następnie';
$strAnIndex = 'Do %s dodany został indeks';
$strAny = 'Dowolny';
$strAnyHost = 'Dowolny host';
$strAnyUser = 'Dowolny użytkownik';
$strApproximateCount = 'Być może w przybliżeniu. Zobacz FAQ 3.11';
$strAPrimaryKey = 'Do %s dodany został klucz podstawowy';
$strArabic = 'Arabski';
$strArmenian = 'Ormiański';
$strAscending = 'Rosnąco';
$strAtBeginningOfTable = 'Na początku tabeli';
$strAtEndOfTable = 'Na końcu tabeli';
$strAttr = 'Atrybuty';
$strAutodetect = 'Autodetekcja';
$strAutomaticLayout = 'Układ automatyczny';

$strBack = 'Powrót';
$strBaltic = 'Bałtycki';
$strBeginCut = 'TNIJ STĄD';
$strBeginRaw = 'SUROWE DANE STĄD';
$strBinary = ' Binarne ';
$strBinaryDoNotEdit = ' Binarne - nie do edycji ';
$strBinaryLog = 'Dziennik binarny';
$strBinLogEventType = 'Typ zdarzenia';
$strBinLogInfo = 'Informacje';
$strBinLogName = 'Nazwa dziennika';
$strBinLogOriginalPosition = 'Oryginalna pozycja';
$strBinLogPosition = 'Pozycja';
$strBinLogServerId = 'ID serwera';
$strBookmarkAllUsers = 'Pozwól na dostęp wszystkim użytkownikom';
$strBookmarkDeleted = 'Zapamiętane zapytanie SQL zostało usunięte.';
$strBookmarkLabel = 'Nazwa';
$strBookmarkQuery = 'Zapamiętane zapytanie SQL';
$strBookmarkThis = 'Pamiętaj zapytanie SQL';
$strBookmarkView = 'Tylko do pokazania';
$strBrowseForeignValues = 'Przeglądaj zewnętrzne wartości';
$strBrowse = 'Przeglądaj';
$strBufferPoolActivity = 'Aktywność rezerw buforowych';
$strBufferPool = 'Rezerwy buforowe';
$strBufferPoolUsage = 'Użycie rezerw buforowych';
$strBufferReadMisses = 'Chybienia odczytu';
$strBufferReadMissesInPercent = 'Chybienia odczytu w %';
$strBufferWriteWaitsInPercent = 'Oczekiwania zapisu w %';
$strBufferWriteWaits = 'Oczekiwania na zapis';
$strBulgarian = 'Bułgarski';
$strBusyPages = 'Strony używane';
$strBzError = 'phpMyAdminowi nie udało się skompresować zrzutu z powodu zepsutego rozszerzenia Bz2 w tej wersji php. Jest bardzo zalecane by ustawić dyrektywę <code>$cfg[\'BZipDump\']</code> w pliku konfiguracyjnym phpMyAdmina na <code>FALSE</code>. Jeśli chcesz użyć funkcji kompresji Bz2, php powinien zostać zaktualizowany do najnowszej wersji. Szczegóły można zobaczyć w raporcie na temat błędów php %s.';
$strBzip = '".bz2"';

$strCalendar = 'Kalendarz';
$strCannotLogin = 'Nie udało się zalogować na serwer MySQL';
$strCantLoad = 'nie udało się załadować modułu %s,<br />proszę sprawdzić konfigurację PHP';
$strCantLoadRecodeIconv = 'Nie udało się załadować rozszerzeń iconv lub recode, które są niezbędne do konwersji kodowania znaków, skonfiguruj php tak, by mógł używać tych rozszerzeń albo zablokuj konwersję kodowania znaków w phpMyAdminie.';
$strCantRenameIdxToPrimary = 'Nie można zmienić nazwy indeksu na PRIMARY!';
$strCantUseRecodeIconv = 'Nie udało się użyć ani funkcji iconv, ani libiconv, mimo że rozszerzenia zgłaszają się jako załadowane. Sprawdź swoją konfigurację php.';
$strCardinality = 'Moc';
$strCaseInsensitive = 'bez rozróżniania wielkości liter';
$strCaseSensitive = 'z rozróżnianiem wielkości liter';
$strCentralEuropean = 'Środkowoeuropejski';
$strChangeCopyModeCopy = '... pozostaw starego.';
$strChangeCopyModeDeleteAndReload = ' ... usuń starego z tabel użytkowników, a następnie przeładuj uprawnienia.';
$strChangeCopyModeJustDelete = ' ... usuń starego z tabel użytkowników.';
$strChangeCopyModeRevoke = ' ... odbierz wszystkie aktywne uprawnienia staremu, a następnie go usuń.';
$strChangeCopyMode = 'Utwórz nowego użytkownika z takimi samymi uprawnieniami i ...';
$strChangeCopyUser = 'Zmień dane użytkownika / Skopiuj użytkownika';
$strChangeDisplay = 'Wybierz wyświetlane pole';
$strChangePassword = 'Zmień hasło';
$strChange = 'Zmień';
$strCharsetOfFile = 'Zestaw znaków dla pliku:';
$strCharsetsAndCollations = 'Zestawy znaków i metody porównywania napisów';
$strCharsets = 'Zestawy znaków';
$strCharset = 'Zestaw znaków';
$strCheckAll = 'Zaznacz wszystkie';
$strCheckOverhead = 'Zaznacz nieoptymalne';
$strCheckPrivsLong = 'Sprawdź uprawnienia bazy danych &quot;%s&quot;.';
$strCheckPrivs = 'Sprawdź uprawnienia';
$strCheckTable = 'Sprawdź tabelę';
$strChoosePage = 'Proszę wybrać stronę do edycji';
$strColComFeat = 'Wyświetl komentarze dla kolumn';
$strCollation = 'Metoda porównywania napisów';
$strColumnNames = 'Nazwy kolumn';
$strColumnPrivileges = 'Uprawnienia specyficzne dla kolumn';
$strCommand = 'Polecenie';
$strCommentsForTable = 'KOMENTARZE TABELI';
$strComments = 'Komentarze';
$strCompatibleHashing = 'Kompatybilny z MySQL-em&nbsp;4.0';
$strCompleteInserts = 'Pełne dodania';
$strCompression = 'Kompresja';
$strConfigFileError = 'phpMyAdmin nie zdołał odczytać Twojego pliku konfiguracji!<br />Może się to zdarzyć, jeśli php znajdzie w nim błąd składniowy lub nie może znaleźć tego pliku.<br />Proszę wywołać bezpośrednio plik konfiguracyjny używając poniższego linku i odczytać otrzymane komunikat(y) o błędach. W większości przypadków brakuje gdzieś cudzysłowu lub średnika.<br />Jeżeli otrzymasz pustą stronę, wszystko jest w porządku.';
$strConfigureTableCoord = 'Proszę skonfigurować współrzędnie dla tabeli %s';
$strConnectionError = 'Nie udało się nawiązać połączenia: błędne ustawienia.';
$strConnections = 'Połączenia';
$strConstraintsForDumped = 'Ograniczenia dla zrzutów tabel';
$strConstraintsForTable = 'Ograniczenia dla tabeli';
$strCookiesRequired = 'Odtąd musi być włączona obsługa "cookies".';
$strCopyDatabaseOK = 'Baza danych %s została skopiowana do %s';
$strCopy = 'Kopiuj';
$strCopyTableOK = 'Tabela %s została skopiowana do %s.';
$strCopyTableSameNames = 'Nie można skopiować tabeli do niej samej!';
$strCopyTable = 'Skopiuj tabelę do (bazadanych<b>.</b>tabela):';
$strCouldNotKill = 'phpMyAdminowi nie udało się unicestwić wątku %s. Prawdopodobnie został on już zamknięty.';
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE przed skopiowaniem';
$strCreateIndexTopic = 'Utwórz nowy indeksu';
$strCreateIndex = 'Utwórz indeks dla %s kolumn';
$strCreateNewDatabase = 'Utwórz nową bazę danych';
$strCreateNewTable = 'Utwórz nową tabelę w bazie danych %s';
$strCreatePage = 'Utwórz nową stronę';
$strCreatePdfFeat = 'Tworzenie PDF-ów';
$strCreate = 'Utwórz';
$strCreationDates = 'Daty utworzenia/aktualizacji/sprawdzenia';
$strCriteria = 'Kryteria';
$strCroatian = 'Chorwacki';
$strCSVOptions = 'Opcje CSV';
$strCyrillic = 'Cyrylica';
$strCzech = 'Czeski';
$strCzechSlovak = 'Czesko-słowacki';

$strDanish = 'Duński';
$strDatabase = 'Baza danych';
$strDatabaseEmpty = 'Nazwa bazy danych jest pusta!';
$strDatabaseExportOptions = 'Opcje eksportu bazy danych';
$strDatabaseHasBeenDropped = 'Baza danych %s została usunięta.';
$strDatabaseNoTable = 'Ta baza danych nie zawiera żadnej tabeli!';
$strDatabases = 'Bazy danych';
$strDatabasesDropped = '%s baz danych zostało pomyślnie usuniętych.';
$strDatabasesStatsDisable = 'Wyłącz statystyki';
$strDatabasesStatsEnable = 'Włącz statystyki';
$strDatabasesStatsHeavyTraffic = 'Uwaga: Włączenie statystyk baz danych może spowodować duży ruch pomiędzy serwerem WWW a serwerem MySQL.';
$strDatabasesStats = 'Statystyki baz danych';
$strData = 'Dane';
$strDataDict = 'Słownik danych';
$strDataOnly = 'Tylko dane';
$strDataPages = 'Strony zawierające dane';
$strDBComment = 'Komentarz bazy danych: ';
$strDBCopy = 'Kopiuj bazę danych do';
$strDBGContextID = 'ID kontekstu';
$strDBGContext = 'Kontekst';
$strDBGHits = 'Trafienia';
$strDBGLine = 'Linia';
$strDBGMaxTimeMs = 'Maksymalny czas, ms';
$strDBGMinTimeMs = 'Minimalny czas, ms';
$strDBGModule = 'Moduł';
$strDBGTimePerHitMs = 'Czas/trafienie, ms';
$strDBGTotalTimeMs = 'Całkowity czas, ms';
$strDbPrivileges = 'Uprawnienia specyficzne dla baz danych';
$strDBRename = 'Zmień nazwę bazy danych na';
$strDbSpecific = 'specyficzne dla bazy danych';
$strDefault = 'Domyślnie';
$strDefaultEngine = '%s to domyślny mechanizm składowania tego serwera MySQL.';
$strDefaultValueHelp = 'Dla wartości domyślnych, proszę wprowadzić po prostu pojedynczą wartość, bez cytowania odwrotnym ukośnikiem czy ujmowania w cudzysłowy, używając takiego formatu: a';
$strDefragment = 'Tablica defragmentacji';
$strDelayedInserts = 'Użyj opóźnionych dodań';
$strDeleteAndFlushDescr = 'Jest to najzgrabniejszy sposób, ale przeładowanie uprawnień może potrwać jakiś czas.';
$strDeleteAndFlush = 'Usuń użytkowników, a następnie przeładuj uprawnienia.';
$strDeleted = 'Rekord został skasowany';
$strDeletedRows = 'Skasowane rekordy:';
$strDelete = 'Usuń';
$strDeleting = 'Usuwanie %s';
$strDelOld = 'Aktualna strona ma powiązania z tabelą, która już nie istnieje. Czy chcesz usunąć te powiązania?';
$strDescending = 'Malejąco';
$strDescription = 'Opis';
$strDictionary = 'słownik';
$strDirtyPages = 'Strony brudne';
$strDisabled = 'wyłączone';
$strDisableForeignChecks = 'Wyłącz sprawdzanie kluczy zewnętrznych';
$strDisplayFeat = 'Funkcje wyświetlania';
$strDisplayOrder = 'Kolejność wyświetlania:';
$strDisplayPDF = 'Wyświetl schemat PDF';
$strDoAQuery = 'Wykonaj "zapytanie przez przykład" (znak globalny: "%")';
$strDocu = 'Dokumentacja';
$strDoYouReally = 'Czy na pewno wykonać ';
$strDropDatabaseStrongWarning = 'Masz zamiar ZNISZCZYĆ całą bazę danych!';
$strDropSelectedDatabases = 'Usuń wybrane bazy danych';
$strDropUsersDb = 'Usuń bazy danych o takich samych nazwach jak użytkownicy.';
$strDrop = 'Usuń';
$strDumpingData = 'Zrzut danych tabeli';
$strDumpSaved = 'Zrzut został zapisany do pliku %s.';
$strDumpXRows = 'Zrzuć %s wierszy zaczynając od wiersza %s.';
$strDynamic = 'zmienny';

$strEdit = 'Edytuj';
$strEditPDFPages = 'Edytuj strony PDF';
$strEditPrivileges = 'Edytuj uprawnienia';
$strEffective = 'Efektywne';
$strEmptyResultSet = 'MySQL zwrócił pusty wynik (zero rekordów).';
$strEmpty = 'Wyczyść';
$strEnabled = 'włączone';
$strEncloseInTransaction = 'Obejmij eksport transakcją';
$strEndCut = 'TNIJ DOTĄD';
$strEnd = 'Koniec';
$strEndRaw = 'SUROWE DANE DOTĄD';
$strEngineAvailable = '%s jest dostępny na tym serwerze MySQL.';
$strEngineDisabled = 'Mechanizm %s został wyłączony w tym serwerze MySQL.';
$strEngines = 'Mechanizmy';
$strEngineUnsupported = 'Ten serwer MySQL nie wspiera mechanizmu składowania %s.';
$strEnglish = 'Angielski';
$strEnglishPrivileges = ' Uwaga: Uprawnienia MySQL są oznaczone w języku angielskim ';
$strError = 'Błąd';
$strEscapeWildcards = 'Aby użyć symboli wieloznacznych _ i % w znaczeniu dosłownym, należy je poprzedzić znakiem \\';
$strEstonian = 'Estoński';
$strExcelEdition = 'Wydanie Excela';
$strExcelOptions = 'Opcje Excela';
$strExecuteBookmarked = 'Wykonaj zapamiętanego zapytania';
$strExplain = 'Wyjaśnij SQL';
$strExport = 'Eksport';
$strExtendedInserts = 'Rozszerzone dodania';
$strExtra = 'Dodatkowy';

$strFailedAttempts = 'Nieudane próby';
$strFieldHasBeenDropped = 'Pole %s zostało usunięte';
$strField = 'Pole';
$strFieldsEmpty = ' Liczba pól jest pusta! ';
$strFieldsEnclosedBy = 'Pola zawarte w';
$strFieldsEscapedBy = 'Pola poprzedzone przez';
$strFields = 'Pola';
$strFieldsTerminatedBy = 'Pola oddzielane przez';
$strFileAlreadyExists = 'Plik %s już istnieje na serwerze, zmień nazwę pliku lub zaznacz opcję nadpisywania plików.';
$strFileCouldNotBeRead = 'Nie można odczytać pliku';
$strFileNameTemplateHelp = 'Jako nazwy bazy danych użyj __DB__, jako nazwy tabeli __TABLE__, a by określić czas - dowolnych opcji %sstrftime%s; rozszerzenia zostaną dodane automatycznie. Każdy inny tekst zostanie zachowany.';
$strFileNameTemplateRemember = 'pamiętaj szablon';
$strFileNameTemplate = 'Szablon nazwy';
$strFixed = 'stały';
$strFlushPrivilegesNote = 'Uwaga: phpMyAdmin pobiera uprawnienia użytkowników wprost z tabeli uprawnień MySQL-a. Zawartość tej tabeli, jeśli zostały w niej dokonane ręczne zmiany, może się różnić od uprawnień jakich faktycznie używa serwer. W takim przypadku powinieneś przed dalszą pracą %sprzeładować uprawnienia%s.';
$strFlushTable = 'Przeładuj tabelę ("FLUSH")';
$strFormat = 'Format';
$strFormEmpty = 'Brakująca wartość w formularzu!';
$strFreePages = 'Strony puste';
$strFullText = 'Pełny tekst';
$strFunction = 'Funkcja';

$strGenBy = 'Wygenerowany przez';
$strGeneralRelationFeat = 'Ogólne funkcje relacyjne';
$strGenerate = 'Generuj';
$strGeneratePassword = 'Generuj hasło';
$strGenTime = 'Czas wygenerowania';
$strGeorgian = 'Gruziński';
$strGerman = 'Niemiecki';
$strGlobal = 'globalnie';
$strGlobalPrivileges = 'Globalne uprawnienia';
$strGlobalValue = 'Wartość globalna';
$strGo = 'Wykonaj';
$strGrantOption = 'Nadawanie';
$strGreek = 'Grecki';
$strGzip = '".gz"';

$strHasBeenAltered = 'zostało zamienione.';
$strHasBeenCreated = 'zostało utworzone.';
$strHaveToShow = 'Musisz wybrać przynajmniej jedną kolumnę do wyświetlenia';
$strHebrew = 'Hebrajski';
$strHexForBinary = 'Użyj liczb szesnastkowych w przypadku pól binarnych';
$strHomepageOfficial = 'Oficjalna strona phpMyAdmina';
$strHome = 'Wejście';
$strHostEmpty = 'Brak nazwy hosta!';
$strHost = 'Host';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Opcje eksportu do formatu Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Opcje eksportu do formatu Microsoft Word 2000';
$strHungarian = 'Węgierski';

$strIcelandic = 'Islandzki';
$strId = 'ID';
$strIdxFulltext = 'Pełny tekst';
$strIgnore = 'Ignoruj';
$strIgnoreInserts = 'Użyj ignorowanych wstawień';
$strIgnoringFile = 'Plik %s jest ignorowany';
$strImportDocSQL = 'Import plików docSQL';
$strImportFiles = 'Import plików';
$strImportFinished = 'Import zakończony';
$strIndexes = 'Indeksy';
$strIndexHasBeenDropped = 'Klucz %s został usunięty';
$strIndex = 'Indeks';
$strIndexName = 'Nazwa indeksu :';
$strIndexType = 'Rodzaj indeksu :';
$strIndexWarningMultiple = 'Dla kolumny `%s` zostało utworzonych wiele indeksów';
$strIndexWarningPrimary = 'Klucze PRIMARY i INDEX nie powinny dotyczyć tej samej kolumny `%s`';
$strIndexWarningTable = 'Problemy z indeksami tabeli `%s`';
$strIndexWarningUnique = 'Klucze UNIQUE i INDEX nie powinny dotyczyć tej samej kolumny `%s`';
$strInnoDBAutoextendIncrementDesc = 'Rozmiar o jaki automatycznie powiększy się tabela, kiedy zostanie zapełniona.';
$strInnoDBAutoextendIncrement = 'Przyrost autoextend';
$strInnoDBBufferPoolSizeDesc = 'Ilość pamięci, której InnoDB używa do buforowania danych i indeksów swoich tabel.';
$strInnoDBBufferPoolSize = 'Rozmiar rezerw buforowych';
$strInnoDBDataFilePath = 'Pliki danych';
$strInnoDBDataHomeDirDesc = 'Wspólna część ścieżki do wszystkich plików danych InnoDB.';
$strInnoDBDataHomeDir = 'Katalog domowy danych';
$strInnoDBPages = 'stron';
$strInnodbStat = 'Status InnoDB';
$strInsecureMySQL = 'Twój plik konfiguracyjny zawiera ustawienia (konto roota bez hasła), które odpowiadają domyślnemu uprzywilejowanemu kontu MySQL. Twój serwer MySQL działa z takim ustawieniem, jest otwarty dla włamywaczy. Ta luka w bezpieczeństwie naprawdę powinna zostać naprawiona.';
$strInsertAsNewRow = 'Dodaj jako nowy rekordu';
$strInsert = 'Dodaj';
$strInsertedRowId = 'Id wstawionego wiersza:';
$strInsertedRows = 'Wprowadzone rekordy:';
$strInsertNewRow = 'Dodaj nowy rekord';
$strInternalNotNecessary = '* Wewnętrzna relacja nie jest konieczna gdy istnieje również w InnoDB.';
$strInternalRelations = 'Wewnętrzne relacje';
$strInUse = 'w użyciu';
$strInvalidColumnCount = 'Liczba kolumn musi być większa niż zero.';
$strInvalidFieldAddCount = 'Musisz dodać przynajmniej jedno pole.';
$strInvalidFieldCount = 'Tabela musi mnieć przynajmnie jendo pole.';
$strInvalidRowNumber = '%d nie jest prawidłowym numerem wiersza.';

$strJapanese = 'Japoński';
$strJumpToDB = 'Skok do bazy danych &quot;%s&quot;.';
$strJustDeleteDescr = 'Nim uprawnienia zostaną przeładowane, &quot;usunięci&quot; użytkownicy nadal będą mieli dotychczasowy dostęp do serwera.';
$strJustDelete = 'Po prostu usuń użytkowników z tabeli uprawnień.';

$strKeepPass = 'Nie zmieniaj hasła';
$strKeyname = 'Nazwa klucza';
$strKill = 'Unicestwij';
$strKorean = 'Koreański';

$strLandscape = 'Orientacja pozioma';
$strLatchedPages = 'Stron zatrzaśniętych';
$strLatexCaption = 'Nagłówek tabeli';
$strLatexContent = 'Zawartość tabeli __TABLE__';
$strLatexContinuedCaption = 'Kontynuacja nagłówka tabeli';
$strLatexContinued = '(kontynuacja)';
$strLatexIncludeCaption = 'Załącz nagłówek tabeli';
$strLatexLabel = 'Etykieta klucza';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'Opcje LaTeX-a';
$strLatexStructure = 'Struktura tabeli __TABLE__';
$strLatvian = 'Łotewski';
$strLengthSet = 'Długość/Wartości*';
$strLimitNumRows = 'rekordów na stronie';
$strLinesTerminatedBy = 'Linie zakończone przez';
$strLinkNotFound = 'Łącze nie znalezione';
$strLinksTo = 'Łącze';
$strLithuanian = 'Litewski';
$strLocalhost = 'Host lokalny';
$strLocationTextfile = 'Lokalizacja pliku tekstowego';
$strLoginInformation = 'Dane użytkownika';
$strLogin = 'Login';
$strLogout = 'Wyjście';
$strLogPassword = 'Hasło:';
$strLogServer = 'Serwer';
$strLogUsername = 'Użytkownik:';
$strLongOperation = 'Ta operacja może trwać długo. Czy mimo to kontynuować?';

$strMaximumSize = 'Maksymalny rozmiar: %s%s';
$strMbExtensionMissing = 'Rozszerzenie PHP o nazwie mbstring nie zostało znalezione, a wygląda na to, że używasz wielobajtowego zestawu znaków. Bez rozszerzenia mbstring phpMyAdmin nie ma możliwości poprawnego rozbijania napisów, co może skutkować niespodziewanymi rezultatami.';
$strMbOverloadWarning = 'Opcja mbstring.func_overload jest włączona w pliku konfiguracyjnym PHP. Jest ona niekompatyblina z phpMyAdminem i może powodować utratę niektórych danych!';
$strMIME_available_mime = 'Dostępne typy MIME';
$strMIME_available_transform = 'Dostępne transformacje';
$strMIME_description = 'Opis';
$strMIME_MIMEtype = 'Typ MIME';
$strMIME_nodescription = 'Transformacja ta nie ma opisu.<br />Proszę zapytać autora, co robi %s.';
$strMIME_transformation_note = 'Aby uzyskać listę dostępnych opcji transformacji i ich typów MIME, kliknij na %sopisy transformacji%s';
$strMIME_transformation_options_note = 'Proszę wprowadzić wartości dla tranformacji w następującym formacie: \'a\',\'b\',\'c\'...<br />Jeżeli potrzeba wprowadzić odwrotny ukośnik ("\") lub apostrof ("\'"), należy je poprzedzić odwrotnym ukośnikiem (np.: \'\\\\xyz\' lub \'a\\\'b\').';
$strMIME_transformation_options = 'Opcje transformacji';
$strMIME_transformation = 'Sposób prezentacji danych';
$strMIMETypesForTable = 'TYPY MIME TABELI';
$strMIME_without = 'Typy MIME pisane czcionką pochyloną nie mają oddzielnej funkcji transformacji';
$strModifications = 'Modyfikacje zostały zapamiętane';
$strModifyIndexTopic = 'Modyfikacja indeksu';
$strModify = 'Modyfikacja';
$strMoveTableOK = 'Tabela %s została przeniesiona do %s.';
$strMoveTable = 'Przenieś tabelę do (bazadanych<b>.</b>tabela):';
$strMoveTableSameNames = 'Nie można przenieść tabeli do niej samej!';
$strMultilingual = 'wiele języków';
$strMyISAMDataPointerSizeDesc = 'Domyślny rozmiar wskaźnika w bajtach, który jest używany przez CREATE TABLE dla tabel MyISAM, gdy nie określono opcji MAX_ROWS.';
$strMyISAMDataPointerSize = 'Rozmiar wskaźnika danych';
$strMyISAMMaxExtraSortFileSizeDesc = 'Jeżeli plik tymczasowy użyty przy szybkim tworzeniu indeksu MyISAM byłby większy o wartość tu określoną, niż w wypadku zastosowania metody pamięci podręcznej kluczy, preferuj tę drugą metodę.';
$strMyISAMMaxExtraSortFileSize = 'Maksymalny rozmiar pliku tymczasowego dla tworzenia indeksu';
$strMyISAMMaxSortFileSizeDesc = 'Maksymalny rozmiar pliku tymczasowego, którego może zostać użyty przy ponownym tworzeniu indeksu MyISAM (podczas operacji REPAIR TABLE, ALTER TABLE lub LOAD DATA INFILE).';
$strMyISAMMaxSortFileSize = 'Maksymalny rozmiar pliku tymczasowego dla sortowania';
$strMyISAMRecoverOptionsDesc = 'Tryb w którym po awarii tabele MyISAM są automatycznie naprawiane; włączany przez opcję startową serwera --myisam-recover.';
$strMyISAMRecoverOptions = 'Tryb automatycznej naprawy';
$strMyISAMRepairThreadsDesc = 'Wartość większa niż 1 oznacza, że indeksy tabel MyISAM są tworzone współbieżnie (każdy indeks ma swój wątek) podczas naprawy przez proces sortujący.';
$strMyISAMRepairThreads = 'Liczba wątków naprawiających';
$strMyISAMSortBufferSizeDesc = 'Bufor, który jest alokowany w czasie sortowania indeksów MyISAM podczas operacji REPAIR TABLE albo gdy indeksy są tworzone przez polecenia CREATE INDEX lub ALTER TABLE.';
$strMyISAMSortBufferSize = 'Rozmiar bufora dla sortowania';
$strMySQLCharset = 'System kodowania znaków dla MySQL';
$strMySQLConnectionCollation = 'System porównań dla połączenia MySQL';
$strMySQLReloaded = 'MySQL przeładowany.';
$strMySQLSaid = 'MySQL zwrócił komunikat: ';
$strMySQLServerProcess = 'MySQL %pma_s1% uruchomiony na %pma_s2%, użytkownik %pma_s3%';
$strMySQLShowProcess = 'Pokaż procesy';
$strMySQLShowStatus = 'Informacje o stanie serwera MySQL';
$strMySQLShowVars = 'Zmienne systemowe serwera MySQL';

$strName = 'Nazwa';
$strNext = 'Następne';
$strNoActivity = 'Brak aktywności przez co najmniej %s sekund, proszę zalogować się jeszcze raz';
$strNoDatabases = 'Brak baz danych';
$strNoDatabasesSelected = 'Żadna baza danych nie został wybrana.';
$strNoDescription = 'brak opisu';
$strNoDetailsForEngine = 'Brak szczegółowych informacji o tym mechanizmie składowania';
$strNoDropDatabases = 'Polecenie "DROP DATABASE" jest zablokowane.';
$strNoExplain = 'Pomiń wyjaśnienie SQL';
$strNoFrames = 'phpMyAdmin jest bardziej przyjazny w przeglądarkach <b>obsługujących ramki</b>';
$strNoIndex = 'Brak zdefiniowanego indeksu!';
$strNoIndexPartsDefined = 'Brak zdefiniowanych części indeksu!';
$strNoModification = 'Bez zmian';
$strNone = 'Brak';
$strNo = 'Nie';
$strNoOptions = 'Ten format nie ma żadnych opcji';
$strNoPassword = 'Brak hasła';
$strNoPermission = 'Serwer WWW nie ma praw do zapisu pliku %s.';
$strNoPhp = 'bez kodu PHP';
$strNoPrivileges = 'Brak uprawnień';
$strNoRights = 'Brak wystarczających uprawnień!';
$strNoRowsSelected = 'Żaden wiersz nie został zaznaczony';
$strNoSpace = 'Brak miejsca na zapis pliku %s.';
$strNoTablesFound = 'Nie znaleziono tabeli w bazie danych.';
$strNoThemeSupport = 'Brak obsługi motywów graficznych, proszę sprawdzić konfigurację i/lub motywy graficzne w katalogu %s.';
$strNotNumber = 'To nie jest liczba!';
$strNotOK = 'błąd';
$strNotSet = 'Tabela <b>%s</b> nie została znaleziona lub nie jest ustawiona w %s';
$strNoUsersFound = 'Nie znaleziono użytkownika(ów).';
$strNoValidateSQL = 'Pomiń sprawdzanie poprawności SQL';
$strNull = 'Null';
$strNumSearchResultsInTable = '%s trafień wewnątrz tabeli <i>%s</i>';
$strNumSearchResultsTotal = '<b>W sumie:</b> <i>%s</i> trafień';
$strNumTables = 'Tabele';

$strOK = 'OK';
$strOperations = 'Operacje';
$strOperator = 'Operator';
$strOptimizeTable = 'Optymalizuj tabelę';
$strOr = 'lub';
$strOverhead = 'Nadmiar';
$strOverwriteExisting = 'Nadpisuj istniejące pliki';

$strPageNumber = 'Numer strony:';
$strPagesToBeFlushed = 'Strony do opróżnienia';
$strPaperSize = 'Rozmiar papieru';
$strPartialText = 'Skrócony tekst';
$strPasswordChanged = 'Hasło dla %s zostało pomyślnie zmienione.';
$strPasswordEmpty = 'Puste hasło!';
$strPassword = 'Hasło';
$strPasswordHashing = 'Sposób kodowania haseł';
$strPasswordNotSame = 'Hasła nie są identyczne!';
$strPdfDbSchema = 'Schemat bazy danych "%s" - strona %s';
$strPdfInvalidTblName = 'Tabela "%s" nie istnieje!';
$strPdfNoTables = 'Brak tabel';
$strPerHour = 'na godzinę';
$strPerMinute = 'na minutę';
$strPerSecond = 'na sekundę';
$strPersian = 'Perski';
$strPhoneBook = 'książka telefoniczna';
$strPHP40203 = 'Używasz PHP w wersji 4.2.3, która ma poważny błąd w obsłudze napisów wielobajtowych (mbstring). Zobacz raport na temat błędów PHP nr 19404. Nie zaleca się używania tej wersji PHP z phpMyAdminem.';
$strPhp = 'Utwórz kod PHP';
$strPHPVersion = 'Wersja PHP';
$strPmaDocumentation = 'Dokumentacja phpMyAdmina';
$strPmaUriError = 'Dyrektywa <tt>$cfg[\'PmaAbsoluteUri\']</tt> musi być ustawiona w pliku konfiguracyjnym!';
$strPolish = 'Polski';
$strPortrait = 'Orientacja pionowa';
$strPos1 = 'Początek';
$strPrevious = 'Poprzednie';
$strPrimaryKeyHasBeenDropped = 'Klucz podstawowy został usunięty';
$strPrimaryKeyName = 'Nazwą podstawowego klucza musi być... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>musi</b> być nazwą <b>jedynie</b> klucza podstawowego!)';
$strPrimary = 'Podstawowy';
$strPrint = 'Drukuj';
$strPrintViewFull = 'Widok do druku (z pełnymi tekstami)';
$strPrintView = 'Widok do druku';
$strPrivDescAllPrivileges = 'Wszystkie uprawnienia, oprócz GRANT.';
$strPrivDescAlter = 'Pozwól zmieniać strukturę istniejących tabel.';
$strPrivDescAlterRoutine = 'Pozwól modyfikować i usuwać procedury składowane.';
$strPrivDescCreateDb = 'Pozwól tworzyć nowe bazy danych i tabele.';
$strPrivDescCreateRoutine = 'Pozwól tworzyć procedury składowane.';
$strPrivDescCreateTbl = 'Pozwól tworzyć nowe tabele.';
$strPrivDescCreateTmpTable = 'Pozwala tworzyć tabele tymczasowe.';
$strPrivDescCreateUser = 'Pozwól tworzyć, usuwać i zmieniać nazwy kont użytkowników.';
$strPrivDescCreateView = 'Pozwól tworzyć perspektywy.';
$strPrivDescDelete = 'Pozwól usuwać dane.';
$strPrivDescDropDb = 'Pozwól usuwać bazy danych i tabele.';
$strPrivDescDropTbl = 'Pozwól usuwać tabele.';
$strPrivDescExecute5 = 'Pozwól wykonywać procedury składowane.';
$strPrivDescExecute = 'Pozwól uruchamiać zapamiętane procedury; Nie ma żadnych skutków w tej wersji MySQL.';
$strPrivDescFile = 'Pozwól importować i eksportować dane z/do plików.';
$strPrivDescGrant = 'Pozwól dodawać użytkowników i nadawać uprawnienia bez przeładowywania tabeli uprawnień.';
$strPrivDescIndex = 'Pozwól tworzyć i usuwać indeksy.';
$strPrivDescInsert = 'Pozwól wstawiać i zamieniać dane.';
$strPrivDescLockTables = 'Pozwól blokować tabele dla aktualnego wątku.';
$strPrivDescMaxConnections = 'Ogranicz liczbę nowych połączeń, które może otworzyć użytkownik w ciągu godziny.';
$strPrivDescMaxQuestions = 'Ogranicz liczbę zapytań, które może wysłać użytkownik w ciągu godziny.';
$strPrivDescMaxUpdates = 'Ogranicz liczbę poleceń zmieniających jakąkolwiek tabelę lub bazę danych, które może wykonać użytkownik w ciągu godziny.';
$strPrivDescProcess3 = 'Pozwól unicestwiać procesy innych użytkowników.';
$strPrivDescProcess4 = 'Pozwól zobaczyć pełną listę zapytań na liście procesów.';
$strPrivDescReferences = 'Nie ma żadnych skutków w tej wersji MySQL.';
$strPrivDescReload = 'Pozwól przeładowywać ustawienia serwera i opróżniać pamięć podręczną serwera.';
$strPrivDescReplClient = 'Nadaj użytkownikowi prawo, by zapytać gdzie są serwery podrzędne / nadrzędne.';
$strPrivDescReplSlave = 'Potrzebne dla replikacji serwera podrzędnego.';
$strPrivDescSelect = 'Pozwól czytać dane.';
$strPrivDescShowDb = 'Daj dostęp do pełnej listy baz danych.';
$strPrivDescShowView = 'Pozwól wykonywać zapytania SHOW CREATE VIEW.';
$strPrivDescShutdown = 'Pozwól zamknąć serwer.';
$strPrivDescSuper = 'Pozwól na połączenie, nawet jeśli osiągnięta została maksymalna ilość połączeń; Wymagane dla większość operacji administracyjnych, takich jak ustawianie zmiennych globalnych czy unicestwianie wątków innych użytkowników.';
$strPrivDescUpdate = 'Pozwól zmieniać dane.';
$strPrivDescUsage = 'Brak uprawnień.';
$strPrivilegesReloaded = 'Uprawnienia zostały pomyślnie przeładowane.';
$strPrivileges = 'Uprawnienia';
$strProcesslist = 'Lista procesów';
$strPutColNames = 'Umieść nazwy pól w pierwszym rekordzie';

$strQBEDel = 'Usuń';
$strQBEIns = 'Wstaw';
$strQBE = 'Zapytanie przez przykład';
$strQueryFrame = 'Okienko zapytania';
$strQueryOnDb = 'Zapytanie SQL dla bazy danych <b>%s</b>:';
$strQuerySQLHistory = 'Historia SQL';
$strQueryStatistics = '<b>Statystyki zapytań</b>: Od rozpoczęcia jego pracy, do serwera zostało wysłanych %s zapytań.';
$strQueryTime = 'Wykonanie zapytania trwało %01.4f sekund(y)';
$strQueryType = 'Rodzaj zapytania';
$strQueryWindowLock = 'Nie nadpisuj tego zapytania spoza okna';

$strReadRequests = 'Żądań odczytu';
$strReceived = 'Otrzymane';
$strRecords = 'Rekordy';
$strReferentialIntegrity = 'Sprawdź spójność powiązań:';
$strRefresh = 'Odśwież';
$strRelationalSchema = 'Schemat relacyjny';
$strRelationNotWorking = 'Dodatkowe możliwości pracy z połączonymi tabelami zostały wyłączone. Aby dowiedzieć się, dlaczego - kliknij %stutaj%s.';
$strRelationsForTable = 'RELACJE TABELI';
$strRelations = 'Relacje';
$strRelationView = 'Widok relacyjny';
$strReloadFailed = 'Przeładowanie MySQL nie powiodło się.';
$strReloadingThePrivileges = 'Przeładuj uprawnienia';
$strReloadMySQL = 'Przeładuj MySQL';
$strRemoveSelectedUsers = 'Usuń zaznaczonych użytkowników';
$strRenameDatabaseOK = 'Baza danych %s ma nazwę zmienioną na %s';
$strRenameTableOK = 'Tabela %s ma nazwę zmienioną na %s';
$strRenameTable = 'Zmień nazwę tabeli na';
$strRepairTable = 'Napraw tabelę';
$strReplaceNULLBy = 'Zamiana NULL na';
$strReplaceTable = 'Zamiana danych tabeli z plikiem';
$strReset = 'Reset';
$strResourceLimits = 'Ograniczenia zasobów';
$strReType = 'Ponownie';
$strRevokeAndDelete = 'Cofnij wszystkie aktywne uprawnienia użytkownikom, a następnie usuń ich.';
$strRevokeAndDeleteDescr = 'Nim uprawnienia zostaną przeładowane, użytkownicy nadal będą mieli uprawnienie USAGE.';
$strRevoke = 'Cofnij';
$strRevokeMessage = 'Uprawnienia dla %s zostały cofnięte';
$strRomanian = 'Rumuński';
$strRowLength = 'Długość rekordu';
$strRowsFrom = 'rekordów począwszy od';
$strRowSize = ' Rozmiar rekordu ';
$strRowsModeFlippedHorizontal = 'poziomo (obrócone nagłówki)';
$strRowsModeHorizontal = 'poziomo';
$strRowsModeOptions = 'w trybie %s powtórz nagłówki po %s komórkach';
$strRowsModeVertical = 'pionowo';
$strRows = 'Rekordów';
$strRowsStatistic = 'Statystyka rekordów';
$strRunning = 'uruchomiony na %s';
$strRunQuery = 'Wykonaj zapytania';
$strRunSQLQuery = 'Wykonanie zapytania/zapytań SQL do bazy danych %s';
$strRussian = 'Rosyjski';

$strSaveOnServer = 'Zapisz na serwerze w katalogu %s';
$strSave = 'Zachowaj';
$strScaleFactorSmall = 'Współczynnik skali jest za mały, by schemat zmieścił się na jednej stronie';
$strSearchFormTitle = 'Szukaj w bazie danych';
$strSearchInTables = 'Wewnątrz tabel(i):';
$strSearchNeedle = 'Szukane słowa lub wartości (symbol wieloznaczny: "%"):';
$strSearchOption1 = 'przynajmniej jedno ze słów';
$strSearchOption2 = 'wszystkie słowa';
$strSearchOption3 = 'cała fraza';
$strSearchOption4 = 'wyrażenie regularne';
$strSearchResultsFor = 'Szukaj w rezultatach dla "<i>%s</i>" %s:';
$strSearch = 'Szukaj';
$strSearchType = 'Znajdź:';
$strSecretRequired = 'Plik konfiguracyjny wymaga teraz tajnej frazy kodującej (blowfish_secret).';
$strSelectADb = 'Proszę wybrać bazę danych';
$strSelectAll = 'Zaznacz wszystkie';
$strSelectBinaryLog = 'Wybierz dziennik binary do podglądu';
$strSelectFields = 'Wybór pól (co najmniej jedno):';
$strSelectNumRows = 'w zapytaniu';
$strSelectTables = 'Wybierz tabele';
$strSend = 'Zapisz jako plik';
$strSent = 'Wysłane';
$strServerChoice = 'Wybór serwera';
$strServerNotResponding = 'Serwer nie odpowiada';
$strServer = 'Serwer';
$strServerStatus = 'Informacje o działaniu serwera';
$strServerStatusUptime = 'Serwer MySQL działa przez %s. Początek pracy: %s.';
$strServerTabProcesslist = 'Procesy';
$strServerTabVariables = 'Zmienne';
$strServerTrafficNotes = '<b>Ruch na serwerze</b>: Poniższe tabele pokazują statystyki ruchu na tym serwerze MySQL od rozpoczęcia jego pracy.';
$strServerVars = 'Zmienne i ustawienia serwera';
$strServerVersion = 'Wersja serwera';
$strSessionValue = 'Wartość sesji';
$strSetEnumVal = 'Jeżeli pole jest typu "ENUM" lub "SET", wartości wprowadza się w formacie: \'a\',\'b\',\'c\'...<br />Jeżeli potrzeba wprowadzić odwrotny ukośnik ("\") lub apostrof ("\'"), należy je poprzedzić odwrotnym ukośnikiem (np.: \'\\\\xyz\' lub \'a\\\'b\').';
$strShowAll = 'Pokaż wszystko';
$strShowColor = 'Pokaż kolor';
$strShowDatadictAs = 'Format słownika danych';
$strShowFullQueries = 'Pokaż pełne zapytania';
$strShowGrid = 'Pokaż siatkę';
$strShowingRecords = 'Pokaż rekordy ';
$strShowPHPInfo = 'Informacje o PHP';
$strShow = 'Pokaż';
$strShowTableDimension = 'Pokaż wymiary tabel';
$strShowTables = 'Pokaż tabele';
$strShowThisQuery = ' Wywołaj ponownie zapytanie ';
$strSimplifiedChinese = 'Chiński uproszczony';
$strSingly = '(pojedynczo)';
$strSize = 'Rozmiar';
$strSlovak = 'Słowacki';
$strSlovenian = 'Słoweński';
$strSocketProblem = '(lub gniazdo lokalnego serwera MySQL server\'s nie jest skonfigurowane poprawnie)';
$strSortByKey = 'Sortuj wg klucza';
$strSort = 'Sortuj';
$strSpaceUsage = 'Wykorzystanie przestrzeni';
$strSpanish = 'Hiszpański';
$strSplitWordsWithSpace = 'Słowa są rozdzielane znakiem spacji (" ").';
$strSQLExportCompatibility = 'Kompatybilność eksportu SQL';
$strSQLExportType = 'Rodzaj eksportu';
$strSQLOptions = 'Opcje SQL';
$strSQLParserBugMessage = 'Istnieje szansa, że właśnie znalazłeś błąd w analizatorze składni SQL. Zbadaj bliżej swoje zapytanie i sprawdź, czy cudzysłowy są poprawne i dobrze sparowane. Inną możliwą przyczyną niepowodzenia może być to, że wysyłasz plik ze znakami binarnymi poza obszarem tekstu ujętego w cudzysłowy. Możesz również sprawdzić swoje zapytanie SQL poprzez linię poleceń MySQL. W znalezieniu przyczyny problemu może pomóc także - jeśli się pojawi - poniższy opis błędu serwera MySQL. Jeśli nadam masz problemy lub analizator składni zgłasza usterkę a linia poleceń - nie, ogranicz sekwencję zapytań SQL do pojedynczego, które powoduje problemy i zgłosić błąd, dołączając fragment danych zawarty w poniższej sekcji TNIJ:';
$strSQLParserUserError = 'Wygląda na to, że w twoim zapytaniu SQL jest błąd. W znalezieniu przyczyny problemu może pomóc także - jeśli się pojawi - poniższy opis błędu serwera MySQL.';
$strSQLQuery = 'zapytanie SQL';
$strSQLResult = 'Rezultat SQL';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Nieprawidłowy identyfikator';
$strSQPBugUnclosedQuote = 'Niezamknięty cudzysłów';
$strSQPBugUnknownPunctuation = 'Nieznany znak przestankowy';
$strStatCheckTime = 'Ostatnie sprawdzenie';
$strStatCreateTime = 'Utworzenie';
$strStatement = 'Cecha';
$strStatUpdateTime = 'Ostatnia aktualizacja';
$strStatus = 'Status';
$strStorageEngine = 'Mechanizm składowania';
$strStorageEngines = 'Mechanizmy składowania';
$strStrucCSV = 'Dane CSV';
$strStrucData = 'Struktura i dane';
$strStrucDrop = 'Dodaj DROP TABLE';
$strStrucExcelCSV = 'CSV dla MS Excel';
$strStrucNativeExcel = 'Dane w formacie macierzystym MS Excela';
$strStrucOnly = 'Tylko struktura';
$strStructPropose = 'Analiza zawartości';
$strStructure = 'Struktura';
$strSubmit = 'Wyślij';
$strSuccess = 'Zapytanie SQL zostało wykonane pomyślnie';
$strSum = 'Suma';
$strSwedish = 'Szwedzki';
$strSwitchToDatabase = 'Przełącz do skopiowanej bazy danych';
$strSwitchToTable = 'Przełącz na skopiowaną tabelę';

$strTableComments = 'Komentarze tabeli';
$strTableEmpty = 'Brak nazwy tabeli!';
$strTableHasBeenDropped = 'Tabela %s została usunięta';
$strTableHasBeenEmptied = 'Tabela %s została opróżniona';
$strTableHasBeenFlushed = 'Tabela %s została przeładowana';
$strTableMaintenance = 'Zarządzanie tabelą';
$strTableOfContents = 'Spis treści';
$strTableOptions = 'Opcje tabeli';
$strTables = '%s tabel(a)';
$strTableStructure = 'Struktura tabeli dla ';
$strTable = 'Tabela';
$strTableType = 'Typ tabeli';
$strTakeIt = 'użyj';
$strTblPrivileges = 'Uprawnienia specyficzne dla tabel';
$strTextAreaLength = ' To pole może nie dać się edytować<br /> z powodu swojej długości ';
$strThai = 'Tajski';
$strTheme = 'Motyw graficzny / styl';
$strThisHost = 'Ten host';
$strThisNotDirectory = 'To nie był katalog';
$strThreadSuccessfullyKilled = 'Wątek %s został pomyślnie unicestwiony.';
$strTime = 'Czas';
$strToggleScratchboard = 'włącz / wyłącz scratchboard';
$strTotalUC = 'Sumarycznie';
$strTotal = 'wszystkich';
$strTraditionalChinese = 'Chiński tradycyjny';
$strTraditionalSpanish = 'Tradycyjny hiszpański';
$strTraffic = 'Ruch';
$strTransformation_application_octetstream__download = 'Wyświetla link do ściągnięcia binarnych danych z tego pola. Pierwsza opcja to nazwa pliku binarnego. Drugą opcją jest możliwa nazwa pola zawierającego nazwę pliku. Jeżeli dana jest druga opcja, pierwsza musi być pustym napisem';
$strTransformation_application_octetstream__hex = 'Wyświetla szesnastkową reprezentację danych.';
$strTransformation_image_jpeg__inline = 'Wyświetla klikalną miniaturkę; opcje: szerokość,wysokość w pikselach (oryginalne proporcje zostaną zachowane)';
$strTransformation_image_jpeg__link = 'Wyświetla link do tego obrazu (bezpośrednie ściągnięcie bloba).';
$strTransformation_image_png__inline = 'Zobacz image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Bierze pole TIME, TIMESTAMP lub DATETIME i formatuje je używając lokalnego formatu daty. Pierwsza opcja to liczba godzin, jaka zostanie dodana do daty (domyślnie: 0). Druga opcja to inny format daty, zgodny z parametrami dostępnymi dla funkcji PHP strftime().';
$strTransformation_text_plain__external = 'TYLKO LINUX: Uruchamia zewnętrzną aplikację i przekazuje dane pól na standardowe wejście. Zwraca standardowe wyjście tej aplikacji. Domyślnie jest to Tidy, którzy porządkuje kod HTML. Ze względu na bezpieczeństwo, musisz ręcznie zmodyfikować plik libraries/transformations/text_plain__external.inc.php i wstawić narzędzie, na którego uruchamianie pozwalasz. Pierwszą opcją jest liczba programów, których chcesz użyć, a drugą są parametry programu. Jeżeli trzeci parametr jest ustawiony na 1, zostanie dokonana konwersja wyjścia poprzez użycie htmlspecialchars() (Domyślną wartością jest 1). Jeżeli czwarty parametr został ustawiony na 1, zawartość komórki nie będzie zawijana, tak że całe wyjście zostanie pokazane bez zmian formatu (domyślną wartością jest 1)';
$strTransformation_text_plain__formatted = 'Zachowuje oryginalne formatowanie pola. Neutralizowanie znaków niespecjalnych nie jest dokonywane.';
$strTransformation_text_plain__imagelink = 'Wyświetla obrazek i link, pole zawiera nazwę pliku; pierwszą opcję jest prefiks, taki jak "http://domena.com/", drugą opcją jest szerokość w pikselach, trzecią opcją jest wysokość.';
$strTransformation_text_plain__link = 'Wyświetla link, pole zawiera nazwę pliku; pierwsza opcja to prefiks, taki jak "http://domena.com/", druga opcja to tytuł linku.';
$strTransformation_text_plain__substr = 'Pokazuje jedynie część napisu. Pierwsza opcja to offset, od którego ma zacząć się wyświetlanie tekstu (domyślnie 0). Druga opcja to ilość zwracanego tekstu. Jeżeli jest pusta, zwracany jest cały pozostały tekst. Trzecia opcja określa jakie znaki zostaną dodane do wyjścia, jeżeli zwracany jest część napisu (domyślnie: ...) .';
$strTruncateQueries = 'Ucinaj wyświetlane zapytania';
$strTurkish = 'Turecki';
$strType = 'Typ';

$strUkrainian = 'Ukraiński';
$strUncheckAll = 'Odznacz wszystkie';
$strUnicode = 'Unikod';
$strUnique = 'Jednoznaczny';
$strUnknown = 'nieznany';
$strUnselectAll = 'Odznacz wszystkie';
$strUpdatePrivMessage = 'Uaktualniłeś uprawnienia dla %s.';
$strUpdateProfileMessage = 'Profil został uaktualniony.';
$strUpdateQuery = 'Zmień zapytanie';
$strUpdComTab = 'Informacje o tym, jak zaktualizować tabelę Column_comments znajdują się w dokumentacji';
$strUpgrade = 'Poleca się aktualizację do %s w wersji %s lub późniejszej.';
$strUsage = 'Wykorzystanie';
$strUseBackquotes = 'Użyj cudzysłowów z nazwami tabel i pól';
$strUseHostTable = 'Użyj tabeli hostów';
$strUserAlreadyExists = 'Użytkownik %s już istnieje!';
$strUserEmpty = 'Brak nazwy użytkownika!';
$strUserName = 'Nazwa użytkownika';
$strUserNotFound = 'Wybrany użytkownik nie został znaleziony w tabeli uprawnień.';
$strUserOverview = 'Opis użytkownika';
$strUsersDeleted = 'Wybrani użytkownicy zostali pomyślnie usunięci.';
$strUsersHavingAccessToDb = 'Użytkownicy mający dostęp do &quot;%s&quot;';
$strUser = 'Użytkownik';
$strUseTabKey = 'Klawisz TAB przemieszcza pomiędzy wartościami, CTRL+strzałka przenosi w dowolne miejsce';
$strUseTables = 'Użyj tabel';
$strUseTextField = 'Użyj pola tekstowego';
$strUseThisValue = 'Użyj tej wartości';

$strValidateSQL = 'Sprawdź proprawność SQL';
$strValidatorError = 'Analizator składni SQL nie mógł zostać zainicjowany. Sprawdź, czy zainstalowane są niezbędne rozszerzenia php, tak jak zostało to opisane w %sdokumentacji%s.';
$strValue = 'Wartość';
$strVar = 'Zmienna';
$strVersionInformation = 'Informacja o wersji';
$strViewDumpDatabases = 'Zrzut baz danych';
$strViewDumpDB = 'Zrzut bazy danych';
$strViewDump = 'Zrzut tabeli';
$strViewHasBeenDropped = 'Perspektywa %s została usunięta';
$strView = 'Perspektywa';

$strWebServerUploadDirectoryError = 'Katalog ustalony dla uploadu jest nieosiągalny';
$strWebServerUploadDirectory = 'katalog serwera www dla uploadu';
$strWelcome = 'Witamy w %s';
$strWestEuropean = 'Zachodnioeuropejski';
$strWildcard = 'znak wieloznaczny';
$strWindowNotFound = 'Docelowe okno przeglądarki nie mogło być zaktualizowane. Być może okno-rodzic zostało zamknięte lub przeglądarka, uwzględniając ustawienia bezpieczeństwa, blokuje aktualizacje pomiędzy oknami';
$strWithChecked = 'Zaznaczone:';
$strWriteRequests = 'Żądań zapisu';
$strWritingCommentNotPossible = 'Zapisanie komentarza nie jest możliwe';
$strWritingRelationNotPossible = 'Zapisanie relacji nie jest możliwe';
$strWrongUser = 'Błędne pola użytkownik/hasło. Brak dostępu.';

$strXML = 'XML';

$strYes = 'Tak';

$strZeroRemovesTheLimit = 'Uwaga: Ustawienie tych opcji na 0 (zero) usuwa ograniczenie.';
$strZip = '".zip"';

$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
$strCSV = 'CSV';  //to translate
$strImport = 'Import';  //to translate
$strImportFormat = 'Format of imported file';  //to translate
$strFileToImport = 'File to import';  //to translate
$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
$strCSVImportOptions = 'CSV options';  //to translate
$strPartialImport = 'Partial import';  //to translate
$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
$strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
$strInvalidCSVInput = 'Invalid CSV input, could not parse!';  //to translate
$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
$strFlushQueryCache = 'Flush query cache';  //to translate
$strFlushTables = 'Flush (close) all tables';  //to translate
$strHandler = 'Handler';  //to translate
$strJoins = 'Joins';  //to translate
$strKeyCache = 'Key cache';  //to translate
$strMaxConnects = 'max. concurrent connections';  //to translate
$strQueryCache = 'Query cache';  //to translate
$strReplication = 'Replication';  //to translate
$strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
$strShowOpenTables = 'Show open tables';  //to translate
$strShowSlaveHosts = 'Show slave hosts';  //to translate
$strShowSlaveStatus = 'Show slave status';  //to translate
$strShowStatusReset = 'Reset';  //to translate
$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
$strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
$strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
$strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
$strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
$strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
$strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
$strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
$strShowStatusHandler_read_firstDescr = 'The number of times the first entry was read from an index. If this is high, it suggests that the server is doing a lot of full index scans; for example, SELECT col1 FROM foo, assuming that col1 is indexed.';  //to translate
$strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
$strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
$strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
$strShowStatusKey_blocks_not_flushedDescr = 'The number of key blocks in the key cache that have changed but haven\'t yet been flushed to disk. It used to be known as Not_flushed_key_blocks.';  //to translate
$strShowStatusKey_blocks_unusedDescr = 'The number of unused blocks in the key cache. You can use this value to determine how much of the key cache is in use.';  //to translate
$strShowStatusKey_blocks_usedDescr = 'The number of used blocks in the key cache. This value is a high-water mark that indicates the maximum number of blocks that have ever been in use at one time.';  //to translate
$strShowStatusKey_read_requestsDescr = 'The number of requests to read a key block from the cache.';  //to translate
$strShowStatusKey_readsDescr = 'The number of physical reads of a key block from disk. If Key_reads is big, then your key_buffer_size value is probably too small. The cache miss rate can be calculated as Key_reads/Key_read_requests.';  //to translate
$strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
$strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
$strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
$strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
$strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
$strShowStatusQcache_insertsDescr = 'The number of queries added to the cache.';  //to translate
$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
$strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
$strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
$strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
$strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
$strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
$strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
$strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
$strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
$strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
$strShowStatusSlave_runningDescr = 'This is ON if this server is a slave that is connected to a master.';  //to translate
$strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken more than slow_launch_time seconds to create.';  //to translate
$strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
$strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
$strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
$strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache. The cache hit rate can be calculated as Threads_created/Connections. If this value is red you should raise your thread_cache_size.';  //to translate
$strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
$strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
$strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
$strSorting = 'Sorting';  //to translate
$strTempData = 'Temporary data';  //to translate
$strThreads = 'Threads';  //to translate
$strLDI = 'CSV using LOAD DATA';  //to translate
$strLDILocal = 'Use LOCAL keyword';  //to translate
$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
$strTableAlreadyExists = 'Table %s already exists!';  //to translate
$strTransactionCoordinator = 'Transaction coordinator';  //to translate
$strNumberOfFields = 'Number of fields';  //to translate
$strShowingBookmark = 'Showing bookmark';  //to translate
$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
$strMaximalQueryLength = 'Maximal length of created query';  //to translate
$strBookmarkCreated = 'Bookmark %s created';  //to translate
$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
$strEsperanto = 'Esperanto';  //to translate
?>
